@@ -1,6 +1,7 @@
 from ._auth_app import AuthApp
 from ._core_app import CoreApp
 from ._data_app import DataApp
+from ._dev_app import DevApp
 from ._download_app import DownloadApp
 from ._dump_app import DumpApp
 from ._landing_app import LandingApp
@@ -16,6 +17,7 @@ __all__ = [
     "AuthApp",
     "CoreApp",
     "DataApp",
+    "DevApp",
     "DownloadApp",
     "DumpApp",
     "LandingApp",
