@@ -10,6 +10,7 @@ from cognite_toolkit._cdf_tk.commands import DownloadCommand
 from cognite_toolkit._cdf_tk.constants import DATA_DEFAULT_DIR
 from cognite_toolkit._cdf_tk.storageio import (
     AssetIO,
+    ChartIO,
     HierarchyIO,
     InstanceIO,
     RawIO,
@@ -17,6 +18,8 @@ from cognite_toolkit._cdf_tk.storageio import (
 from cognite_toolkit._cdf_tk.storageio.selectors import (
     AssetCentricSelector,
     AssetSubtreeSelector,
+    ChartExternalIdSelector,
+    ChartSelector,
     DataSetSelector,
     InstanceSpaceSelector,
     RawTableSelector,
@@ -27,6 +30,7 @@ from cognite_toolkit._cdf_tk.utils.auth import EnvironmentVariables
 from cognite_toolkit._cdf_tk.utils.interactive_select import (
     AssetInteractiveSelect,
     DataModelingSelect,
+    InteractiveChartSelect,
     RawTableInteractiveSelect,
 )
 
@@ -50,6 +54,10 @@ class InstanceFormats(str, Enum):
     ndjson = "ndjson"
 
 
+class ChartFormats(str, Enum):
+    ndjson = "ndjson"
+
+
 class InstanceTypes(str, Enum):
     node = "node"
     edge = "edge"
@@ -71,6 +79,7 @@ class DownloadApp(typer.Typer):
         self.command("assets")(self.download_assets_cmd)
         self.command("hierarchy")(self.download_hierarchy_cmd)
         self.command("instances")(self.download_instances_cmd)
+        self.command("charts")(self.download_charts_cmd)
 
     @staticmethod
     def download_main(ctx: typer.Context) -> None:
@@ -476,3 +485,76 @@ class DownloadApp(typer.Typer):
                 verbose=verbose,
             )
         )
+
+    @staticmethod
+    def download_charts_cmd(
+        ctx: typer.Context,
+        external_ids: Annotated[
+            list[str] | None,
+            typer.Argument(
+                help="List of chart external IDs to download. If not provided, an interactive selection will be made.",
+            ),
+        ] = None,
+        file_format: Annotated[
+            ChartFormats,
+            typer.Option(
+                "--format",
+                "-f",
+                help="Format for downloading the charts.",
+            ),
+        ] = ChartFormats.ndjson,
+        compression: Annotated[
+            CompressionFormat,
+            typer.Option(
+                "--compression",
+                "-z",
+                help="Compression format to use when downloading the instances.",
+            ),
+        ] = CompressionFormat.none,
+        output_dir: Annotated[
+            Path,
+            typer.Option(
+                "--output-dir",
+                "-o",
+                help="Where to download the charts.",
+                allow_dash=True,
+            ),
+        ] = DEFAULT_DOWNLOAD_DIR,
+        limit: Annotated[
+            int,
+            typer.Option(
+                "--limit",
+                "-l",
+                help="The maximum number of charts to download. Use -1 to download all charts.",
+            ),
+        ] = 1000,
+        verbose: Annotated[
+            bool,
+            typer.Option(
+                "--verbose",
+                "-v",
+                help="Turn on to get more verbose output when running the command",
+            ),
+        ] = False,
+    ) -> None:
+        """This command will download Charts from CDF into a temporary directory."""
+        cmd = DownloadCommand()
+        client = EnvironmentVariables.create_from_environment().get_client()
+        selector: ChartSelector
+        if external_ids is None:
+            selected_external_ids = InteractiveChartSelect(client).select_external_ids()
+            selector = ChartExternalIdSelector(external_ids=tuple(selected_external_ids))
+        else:
+            selector = ChartExternalIdSelector(external_ids=tuple(external_ids))
+
+        cmd.run(
+            lambda: cmd.download(
+                selectors=[selector],
+                io=ChartIO(client),
+                output_dir=output_dir,
+                file_format=f".{file_format.value}",
+                compression=compression.value,
+                limit=limit if limit != -1 else None,
+                verbose=verbose,
+            )
+        )
