@@ -8,21 +8,24 @@ from cognite.client.data_classes.data_modeling import ContainerId
 
 from cognite_toolkit._cdf_tk.client import ToolkitClient
 from cognite_toolkit._cdf_tk.commands import (
-    MigrateFilesCommand,
     MigrationCanvasCommand,
     MigrationPrepareCommand,
 )
 from cognite_toolkit._cdf_tk.commands._migrate import MigrationCommand
-from cognite_toolkit._cdf_tk.commands._migrate.adapter import (
-    AssetCentricMigrationIOAdapter,
+from cognite_toolkit._cdf_tk.commands._migrate.creators import (
+    InfieldV2ConfigCreator,
+    InstanceSpaceCreator,
+    SourceSystemCreator,
+)
+from cognite_toolkit._cdf_tk.commands._migrate.data_mapper import AssetCentricMapper
+from cognite_toolkit._cdf_tk.commands._migrate.migration_io import (
+    AssetCentricMigrationIO,
+)
+from cognite_toolkit._cdf_tk.commands._migrate.selectors import (
+    AssetCentricMigrationSelector,
     MigrateDataSetSelector,
     MigrationCSVFileSelector,
-    MigrationSelector,
-    TimeSeriesIOAdapter,
 )
-from cognite_toolkit._cdf_tk.commands._migrate.creators import InstanceSpaceCreator, SourceSystemCreator
-from cognite_toolkit._cdf_tk.commands._migrate.data_mapper import AssetCentricMapper
-from cognite_toolkit._cdf_tk.storageio import AssetIO, EventIO
 from cognite_toolkit._cdf_tk.utils.auth import EnvironmentVariables
 from cognite_toolkit._cdf_tk.utils.cli_args import parse_view_str
 from cognite_toolkit._cdf_tk.utils.interactive_select import (
@@ -47,6 +50,8 @@ class MigrateApp(typer.Typer):
         self.command("timeseries")(self.timeseries)
         self.command("files")(self.files)
         self.command("canvas")(self.canvas)
+        # Uncomment when infield v2 config migration is ready
+        # self.command("infield-configs")(self.infield_configs)
 
     def main(self, ctx: typer.Context) -> None:
         """Migrate resources from Asset-Centric to data modeling in CDF."""
@@ -317,7 +322,7 @@ class MigrateApp(typer.Typer):
         cmd.run(
             lambda: cmd.migrate(
                 selected=selected,
-                data=AssetCentricMigrationIOAdapter(client, AssetIO(client)),
+                data=AssetCentricMigrationIO(client),
                 mapper=AssetCentricMapper(client),
                 log_dir=log_dir,
                 dry_run=dry_run,
@@ -337,11 +342,11 @@ class MigrateApp(typer.Typer):
         kind: AssetCentricKind,
         resource_type: str,
         container_id: ContainerId,
-    ) -> tuple[MigrationSelector, bool, bool]:
+    ) -> tuple[AssetCentricMigrationSelector, bool, bool]:
         if data_set_id is not None and mapping_file is not None:
             raise typer.BadParameter("Cannot specify both data_set_id and mapping_file")
         elif mapping_file is not None:
-            selected: MigrationSelector = MigrationCSVFileSelector(datafile=mapping_file, kind=kind)
+            selected: AssetCentricMigrationSelector = MigrationCSVFileSelector(datafile=mapping_file, kind=kind)
         elif data_set_id is not None:
             parsed_view = parse_view_str(consumption_view) if consumption_view is not None else None
             selected = MigrateDataSetSelector(
@@ -466,7 +471,7 @@ class MigrateApp(typer.Typer):
         cmd.run(
             lambda: cmd.migrate(
                 selected=selected,
-                data=AssetCentricMigrationIOAdapter(client, EventIO(client)),
+                data=AssetCentricMigrationIO(client),
                 mapper=AssetCentricMapper(client),
                 log_dir=log_dir,
                 dry_run=dry_run,
@@ -573,7 +578,7 @@ class MigrateApp(typer.Typer):
         cmd.run(
             lambda: cmd.migrate(
                 selected=selected,
-                data=TimeSeriesIOAdapter(client, skip_linking=skip_linking),
+                data=AssetCentricMigrationIO(client, skip_linking=skip_linking),
                 mapper=AssetCentricMapper(client),
                 log_dir=log_dir,
                 dry_run=dry_run,
@@ -581,11 +586,12 @@ class MigrateApp(typer.Typer):
             )
         )
 
-    @staticmethod
+    @classmethod
     def files(
+        cls,
         ctx: typer.Context,
         mapping_file: Annotated[
-            Path,
+            Path | None,
             typer.Option(
                 "--mapping-file",
                 "-m",
@@ -593,7 +599,51 @@ class MigrateApp(typer.Typer):
                 "This file is expected to have the following columns: [id, dataSetId, space, externalId]."
                 "The dataSetId is optional, and can be skipped. If it is set, it is used to check the access to the dataset.",
             ),
-        ],
+        ] = None,
+        data_set_id: Annotated[
+            str | None,
+            typer.Option(
+                "--data-set-id",
+                "-s",
+                help="The data set ID to select for the files to migrate. If not provided, the dataSetId from the mapping file is used. "
+                "If neither is provided, the default data set for the project is used.",
+            ),
+        ] = None,
+        ingestion_mapping: Annotated[
+            str | None,
+            typer.Option(
+                "--ingestion-mapping",
+                "-i",
+                help="The ingestion mapping to use for the migrated files. If not provided, "
+                "the default mapping to CogniteFile in CogniteCore will be used.",
+            ),
+        ] = None,
+        consumption_view: Annotated[
+            str | None,
+            typer.Option(
+                "--consumption-view",
+                "-c",
+                help="The consumption view to assign to the migrated files Given as space:externalId/version. "
+                "This will be used in Canvas to select which view to use when migrating timeseries. If not provided, "
+                "CogniteFile in CogniteCore will be used.",
+            ),
+        ] = None,
+        log_dir: Annotated[
+            Path,
+            typer.Option(
+                "--log-dir",
+                "-l",
+                help="Path to the directory where logs will be stored. If the directory does not exist, it will be created.",
+            ),
+        ] = Path(f"migration_logs_{TODAY!s}"),
+        skip_linking: Annotated[
+            bool,
+            typer.Option(
+                "--skip-linking",
+                "-x",
+                help="If set, the migration will not create links between the old FileMetadata and the new CogniteFile.",
+            ),
+        ] = False,
         dry_run: Annotated[
             bool,
             typer.Option(
@@ -612,13 +662,33 @@ class MigrateApp(typer.Typer):
         ] = False,
     ) -> None:
         """Migrate Files to CogniteFiles."""
-
         client = EnvironmentVariables.create_from_environment().get_client(enable_set_pending_ids=True)
-        cmd = MigrateFilesCommand()
+
+        selected, dry_run, verbose = cls._prepare_asset_centric_arguments(
+            client=client,
+            mapping_file=mapping_file,
+            data_set_id=data_set_id,
+            consumption_view=consumption_view,
+            ingestion_mapping=ingestion_mapping,
+            dry_run=dry_run,
+            verbose=verbose,
+            kind="FileMetadata",
+            resource_type="file",
+            container_id=ContainerId("cdf_cdm", "CogniteFile"),
+        )
+        cmd = MigrationCommand()
+
+        if data_set_id is None:
+            skip_linking = not questionary.confirm(
+                "Do you want to link old and new Files?", default=not skip_linking
+            ).ask()
+
         cmd.run(
-            lambda: cmd.migrate_files(
-                client,
-                mapping_file=mapping_file,
+            lambda: cmd.migrate(
+                selected=selected,
+                data=AssetCentricMigrationIO(client, skip_linking=skip_linking),
+                mapper=AssetCentricMapper(client),
+                log_dir=log_dir,
                 dry_run=dry_run,
                 verbose=verbose,
             )
@@ -669,3 +739,46 @@ class MigrateApp(typer.Typer):
                 verbose=verbose,
             )
         )
+
+    @staticmethod
+    def infield_configs(
+        ctx: typer.Context,
+        output_dir: Annotated[
+            Path,
+            typer.Option(
+                "--output-dir",
+                "-o",
+                help="Path to the directory where the Infield V2 configuration definitions will be dumped. It is recommended "
+                "to govern these configurations in a git repository.",
+            ),
+        ] = Path("tmp"),
+        dry_run: Annotated[
+            bool,
+            typer.Option(
+                "--dry-run",
+                "-d",
+                help="If set, the migration will not be executed, but only a report of what would be done is printed.",
+            ),
+        ] = False,
+        verbose: Annotated[
+            bool,
+            typer.Option(
+                "--verbose",
+                "-v",
+                help="Turn on to get more verbose output when running the command",
+            ),
+        ] = False,
+    ) -> None:
+        """Creates Infield V2 configurations from existing APM Configurations in CDF."""
+        client = EnvironmentVariables.create_from_environment().get_client()
+
+        cmd = MigrationCommand()
+        cmd.run(
+            lambda: cmd.create(
+                client,
+                creator=InfieldV2ConfigCreator(client),
+                output_dir=output_dir,
+                dry_run=dry_run,
+                verbose=verbose,
+            )
+        )
