@@ -143,7 +143,9 @@ class BuildCommand(ToolkitCommand):
             config.environment.selected = parse_user_selected_modules(selected, organization_dir)
 
         # tracking which project the module is being built for to trace promotion
-        self._additional_tracking_info["project"] = config.environment.project
+        if client:
+            self._additional_tracking_info.project = client.config.project
+            self._additional_tracking_info.cluster = client.config.cdf_cluster
 
         directory_name = "current directory" if organization_dir == Path(".") else f"project '{organization_dir!s}'"
         root_modules = [
@@ -331,15 +333,11 @@ class BuildCommand(ToolkitCommand):
                 build.append(built_module)
 
                 if module.package_id:
-                    package_ids = self._additional_tracking_info.setdefault("packageId", [])
-                    if module.package_id not in package_ids:
-                        package_ids.append(module.package_id)
+                    self._additional_tracking_info.package_ids.add(module.package_id)
 
                 if module.module_id:
-                    module_ids = self._additional_tracking_info.setdefault("moduleIds", [])
-                    module_ids.append(module.module_id)
+                    self._additional_tracking_info.module_ids.add(module.module_id)
 
-                self.tracker.track_module_build(built_module)
         return build
 
     def _build_module_resources(
@@ -494,7 +492,7 @@ class BuildCommand(ToolkitCommand):
             # which is what we do in the deploy step to verify that the source file has not changed.
             source = SourceLocationEager(source_path, calculate_hash(source_path, shorten=True))
 
-            content = variables.replace(content, source_path.suffix)
+            content = variables.replace(content, source_path)
 
             replace_warnings = self._check_variables_replaced(content, module_dir, source_path)
 
