@@ -85,6 +85,10 @@ class Flags(Enum):
         visible=False,
         description="Enables features planned for Cognite Toolkit version 0.7.0",
     )
+    STREAMS = FlagMetadata(
+        visible=True,
+        description="Enables the support for the streams resources",
+    )
 
     def is_enabled(self) -> bool:
         return FeatureFlag.is_enabled(self)
