@@ -6,17 +6,17 @@ from unittest.mock import MagicMock
 import pytest
 
 from cognite_toolkit._cdf_tk.builders import get_loader
-from cognite_toolkit._cdf_tk.loaders import FileLoader, RawDatabaseLoader, RawTableLoader, ResourceLoader
+from cognite_toolkit._cdf_tk.cruds import FileCRUD, RawDatabaseCRUD, RawTableCRUD, ResourceCRUD
 
 
 @pytest.mark.parametrize(
     "content, expected_loader_cls",
     [
-        ("dbName: my_database\n", RawDatabaseLoader),
-        ("dbName: my_database\ntableName: my_table\n", RawTableLoader),
+        ("dbName: my_database\n", RawDatabaseCRUD),
+        ("dbName: my_database\ntableName: my_table\n", RawTableCRUD),
     ],
 )
-def test_get_loader_raw_loaders(content: str, expected_loader_cls: type[ResourceLoader]) -> None:
+def test_get_loader_raw_loaders(content: str, expected_loader_cls: type[ResourceCRUD]) -> None:
     filepath = MagicMock(spec=Path)
     filepath.name = "filelocation.yaml"
     filepath.stem = "filelocation"
@@ -33,4 +33,4 @@ def test_get_loader_file() -> None:
     loader_cls, warning = get_loader(Path("SHOP_model_borgund.File.yaml"), "files", force_pattern=True)
 
     assert warning is None
-    assert loader_cls is FileLoader
+    assert loader_cls is FileCRUD
