@@ -21,7 +21,6 @@ from cognite.client.data_classes.data_modeling import (
     NodeList,
     Space,
     View,
-    ViewId,
 )
 from cognite.client.data_classes.data_modeling.cdm.v1 import CogniteFile, CogniteTimeSeries
 from cognite.client.data_classes.data_modeling.statistics import SpaceStatistics
@@ -32,7 +31,7 @@ from cognite_toolkit._cdf_tk.client.data_classes.extended_filemetadata import (
 )
 from cognite_toolkit._cdf_tk.client.data_classes.extended_timeseries import ExtendedTimeSeries
 from cognite_toolkit._cdf_tk.commands import PurgeCommand
-from cognite_toolkit._cdf_tk.storageio import InstanceViewSelector
+from cognite_toolkit._cdf_tk.storageio.selectors import InstanceViewSelector, SelectedView
 from tests.test_unit.utils import FakeCogniteResourceGenerator
 
 
@@ -233,7 +232,7 @@ class TestPurgeInstances:
         cmd = PurgeCommand(silent=True)
         result = cmd.instances(
             client,
-            InstanceViewSelector(view=ViewId(space="cdf_cdm", external_id="CogniteTimeSeries", version="v1")),
+            InstanceViewSelector(view=SelectedView(space="cdf_cdm", external_id="CogniteTimeSeries", version="v1")),
             dry_run=dry_run,
             auto_yes=True,
             unlink=unlink,
@@ -244,11 +243,16 @@ class TestPurgeInstances:
 
 class TestPurgeSpace:
     @pytest.mark.usefixtures("disable_gzip")
-    @pytest.mark.parametrize("dry_run, include_space", itertools.product([True, False], [True, False]))
+    @pytest.mark.parametrize(
+        "dry_run, include_space,delete_datapoints,delete_file_content,",
+        itertools.product([True, False], [True, False], [True, False], [True, False]),
+    )
     def test_purge(
         self,
         dry_run: bool,
         include_space: bool,
+        delete_datapoints: bool,
+        delete_file_content: bool,
         purge_client: ToolkitClient,
         purge_responses: responses.RequestsMock,
         respx_mock: respx.MockRouter,
@@ -261,6 +265,8 @@ class TestPurgeSpace:
         data_model_count = 3
         edge_count = 40
         node_count = 50
+        ts_count = 14
+        file_count = 7
         rsps.add(
             responses.POST,
             config.create_api_url("/models/statistics/spaces/byids"),
@@ -288,7 +294,7 @@ class TestPurgeSpace:
                 "/models/instances/delete",
             ]
             for url in delete_urls:
-                respx.post(config.create_api_url(url)).mock(side_effect=delete_callback)
+                respx_mock.post(config.create_api_url(url)).mock(side_effect=delete_callback)
             if include_space:
                 rsps.add_callback(
                     method=responses.POST,
@@ -305,28 +311,57 @@ class TestPurgeSpace:
             ]
             if include_space:
                 list_calls.append(("/models/spaces/byids", responses.POST, Space, 1))
+            nodes: list[Node] = []
             for url, method, cls_, count in list_calls:
+                items = [gen.create_instance(cls_) for _ in range(count)]
+                if issubclass(cls_, Node):
+                    nodes.extend(items)
                 rsps.add(
                     method=method,
                     url=config.create_api_url(url),
-                    json={"items": [gen.create_instance(cls_).dump() for _ in range(count)]},
+                    json={"items": [item.dump() for item in items]},
+                )
+
+            retrieve_calls = []
+            if not delete_datapoints:
+                retrieve_calls.append(("/timeseries/byids", ExtendedTimeSeries, ts_count, nodes[:ts_count]))
+            if not delete_file_content:
+                retrieve_calls.append(
+                    ("/files/byids", ExtendedFileMetadata, file_count, nodes[ts_count : ts_count + file_count])
+                )
+
+            for url, cls_, count, resource_nodes in retrieve_calls:
+                resource_list = [gen.create_instance(cls_).dump() for _ in range(count)]
+                for ts, node in zip(resource_list, resource_nodes):
+                    ts["instanceId"] = node.as_id().dump(include_instance_type=False)
+                rsps.add(
+                    method=responses.POST,
+                    url=config.create_api_url(url),
+                    json={"items": resource_list},
                 )
 
         cmd = PurgeCommand(silent=True)
-        results = cmd.space_v2(
+        results = cmd.space(
             purge_client,
             "test_space",
             include_space=include_space,
+            delete_datapoints=delete_datapoints,
+            delete_file_content=delete_file_content,
             dry_run=dry_run,
             auto_yes=True,
             verbose=False,
         )
+        expected_node_count = (
+            node_count
+            - (0 if delete_datapoints or dry_run else ts_count)
+            - (0 if delete_file_content or dry_run else file_count)
+        )
         expected = {
             "containers": container_count,
             "views": view_count,
             "data models": data_model_count,
             "edges": edge_count,
-            "nodes": node_count,
+            "nodes": expected_node_count,
         }
         if include_space:
             expected["spaces"] = 1
